PALM-meteo: palmmeteo_stdplugins/aladin.py File Reference

PALM-meteo

Loading...
Searching...
No Matches
Classes | Namespaces | Functions | Variables
aladin.py File Reference

## Classes
class | palmmeteo_stdplugins.aladin.AladinPlugin
class | palmmeteo_stdplugins.aladin.AladinCoordTransform
class | palmmeteo_stdplugins.aladin.AladinRadPlugin
class | palmmeteo_stdplugins.aladin.BilinearRegridder

## Namespaces
namespace | palmmeteo_stdplugins
namespace | palmmeteo_stdplugins.aladin

## Functions
| palmmeteo_stdplugins.aladin.variable2parameter ()
| palmmeteo_stdplugins.aladin.findnearest (xlon, xlat, point)
| palmmeteo_stdplugins.aladin.transform_from_grib (filename, fileout, cfg, **kwargs)
| palmmeteo_stdplugins.aladin.log_dstat_on (desc, delta)
| palmmeteo_stdplugins.aladin.log_dstat_off (desc, delta)
| palmmeteo_stdplugins.aladin.palm_alad_gw (f, lon, lat, levels, tidx=0)
| palmmeteo_stdplugins.aladin.minterp (interp_heights, data_heights, u, v)
| palmmeteo_stdplugins.aladin.get_wrf_dims (f, lat, lon, xlat, xlong)
| palmmeteo_stdplugins.aladin.calcgw_wrf (f, lat, lon, levels, tidx=0)
| palmmeteo_stdplugins.aladin.aladin_t (f, it)
| palmmeteo_stdplugins.aladin.description_key ()

## Variables
| palmmeteo_stdplugins.aladin.barom_pres = PalmPhysics.barom_lapse0_pres
| palmmeteo_stdplugins.aladin.barom_gp = PalmPhysics.barom_lapse0_gp
| palmmeteo_stdplugins.aladin.g = PalmPhysics.g
| palmmeteo_stdplugins.aladin.ax_ = np.newaxis
int | palmmeteo_stdplugins.aladin.gw_gfs_margin_deg = 5.
int | palmmeteo_stdplugins.aladin.gw_wrf_margin_km = 10.
int | palmmeteo_stdplugins.aladin.gw_alpha = 1.